@@ -79,6 +79,11 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
         if header[:16] != b'SQLite format 3\0':
             raise ValueError('SQLite header not found at start of stream')
 
+        encoding, = unsigned_long.unpack(header[56:60])
+        # 0 if the database is empty. This is not documented at https://www.sqlite.org/fileformat.html
+        if encoding not in (0, 1):
+            raise ValueError('Unsupported encoding')
+
         page_size, = unsigned_short.unpack(header[16:18])
         page_size = 65536 if page_size == 1 else page_size
         num_pages_expected, = unsigned_long.unpack(header[28:32])
@@ -137,7 +142,7 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
                             (0, lambda _: 0) if serial_type == 8 else \
                             (0, lambda _: 1) if serial_type == 9 else \
                             (int((serial_type - 12)/2), lambda raw: raw) if serial_type % 2 == 0 else \
-                            (int((serial_type - 13)/2), lambda raw: raw) if serial_type % 2 == 1 else \
+                            (int((serial_type - 13)/2), lambda raw: raw.decode()) if serial_type % 2 == 1 else \
                             (None, None),
                         )
                     )
@@ -149,10 +154,9 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
                     yield page_number
 
             def get_master_table(master_cells):
-
                 def schema(cur, table_name, sql):
                     cur.execute(sql)
-                    cur.execute("PRAGMA table_info('" + table_name + "');")
+                    cur.execute("PRAGMA table_info('" + table_name.replace("'","''") + "');")
                     rows = cur.fetchall()
                     cols = [d[0] for d in cur.description]
                     return tuple({col: row[i] for i, col in enumerate(cols)} for row in rows)
@@ -162,12 +166,12 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
 
                     return tuple(
                         {
-                            'name': cell[1].decode(),
-                            'info': schema(cur, cell[1].decode(), cell[4].decode()),
+                            'name': cell[1],
+                            'info': schema(cur, cell[1], cell[4]),
                             'root_page': cell[3],
                         }
                         for cell in master_cells
-                        if cell[0] == b'table'
+                        if cell[0] == 'table'
                     )
 
             def process_if_buffered_or_remember(table_name, page_num):
